IncrementalParser

Struct IncrementalParser 

pub struct IncrementalParser<R: Read + Seek, S: ParseState> { /* private fields */ }
An incremental parser for braid archives.

Initially, minimal reading from the archive is performed. As further operations on the archive proceed, the state of the parser gradually accumulates more information.

Implementations

Source

impl IncrementalParser<BufReader<File>, ArchiveOpened>

pub fn open<P: AsRef<Path>>(path: P) -> Result<Self, Error>

Open an archive from a path.

The archive may be a .braidz zip file for a .braid directory.

pub fn open_dir<P: AsRef<Path>>(path: P) -> Result<Self, Error>

Open an archive from a directory.

The archive must be a .braid directory.

pub fn open_braidz_file<P: AsRef<Path>>(path: P) -> Result<Self, Error>

Open an archive from a .braidz zip file.

The archive must be a .braidz zip file.

Source

impl<R: Read + Seek> IncrementalParser<R, ArchiveOpened>

pub fn from_archive(archive: ZipDirArchive<R>) -> Self

Open an archive.

The archive may be a .braidz zip file for a .braid directory.

pub fn parse_basics( self, ) -> Result<IncrementalParser<R, BasicInfoParsed>, Error>

Parse the basic data which can be quickly read from the archive.

pub fn parse_everything( self, ) -> Result<IncrementalParser<R, FullyParsed>, Error>

Parse the entire archive.

Source

impl<R: Read + Seek> IncrementalParser<R, BasicInfoParsed>

pub fn parse_rest(self) -> Result<IncrementalParser<R, FullyParsed>, Error>

Parse the remaining aspects of the archive.

pub fn basic_info(&self) -> &BasicInfoParsed

Source

impl<R: Read + Seek> IncrementalParser<R, FullyParsed>

Source

impl<R: Read + Seek, S: ParseState> IncrementalParser<R, S>

pub fn into_inner(self) -> ZipDirArchive<R>

Consume and return the raw storage archive.

pub fn display(&self) -> Display<'_>

Display the path of the archive.

pub fn path_starter(&mut self) -> PathLike<'_, R>

Get a path-like instance for direct read access to the archive.

You should prefer to use information already parsed from the archive rather than resorting to this low-level function. Consider expanding the parser to provide this information if it is not already implemented.