pub struct IncrementalParser<R: Read + Seek, S: ParseState> { /* private fields */ }Expand description
An incremental parser for braid archives.
Initially, minimal reading from the archive is performed. As further operations on the archive proceed, the state of the parser gradually accumulates more information.
Implementations
Sourceimpl IncrementalParser<BufReader<File>, ArchiveOpened>
impl IncrementalParser<BufReader<File>, ArchiveOpened>
Sourceimpl<R: Read + Seek> IncrementalParser<R, ArchiveOpened>
impl<R: Read + Seek> IncrementalParser<R, ArchiveOpened>
Sourcepub fn from_archive(archive: ZipDirArchive<R>) -> Self
pub fn from_archive(archive: ZipDirArchive<R>) -> Self
Open an archive.
The archive may be a .braidz zip file for a .braid directory.
Sourcepub fn parse_basics(
self,
) -> Result<IncrementalParser<R, BasicInfoParsed>, Error>
pub fn parse_basics( self, ) -> Result<IncrementalParser<R, BasicInfoParsed>, Error>
Parse the basic data which can be quickly read from the archive.
Sourcepub fn parse_everything(
self,
) -> Result<IncrementalParser<R, FullyParsed>, Error>
pub fn parse_everything( self, ) -> Result<IncrementalParser<R, FullyParsed>, Error>
Parse the entire archive.
Sourceimpl<R: Read + Seek> IncrementalParser<R, BasicInfoParsed>
impl<R: Read + Seek> IncrementalParser<R, BasicInfoParsed>
Sourcepub fn parse_rest(self) -> Result<IncrementalParser<R, FullyParsed>, Error>
pub fn parse_rest(self) -> Result<IncrementalParser<R, FullyParsed>, Error>
Parse the remaining aspects of the archive.
pub fn basic_info(&self) -> &BasicInfoParsed
Sourceimpl<R: Read + Seek> IncrementalParser<R, FullyParsed>
impl<R: Read + Seek> IncrementalParser<R, FullyParsed>
pub fn kalman_estimates_info(&self) -> Option<&KalmanEstimatesInfo>
Sourceimpl<R: Read + Seek, S: ParseState> IncrementalParser<R, S>
impl<R: Read + Seek, S: ParseState> IncrementalParser<R, S>
Sourcepub fn into_inner(self) -> ZipDirArchive<R>
pub fn into_inner(self) -> ZipDirArchive<R>
Consume and return the raw storage archive.
Sourcepub fn path_starter(&mut self) -> PathLike<'_, R>
pub fn path_starter(&mut self) -> PathLike<'_, R>
Get a path-like instance for direct read access to the archive.
You should prefer to use information already parsed from the archive rather than resorting to this low-level function. Consider expanding the parser to provide this information if it is not already implemented.